# Changelog

<!--next-version-placeholder-->

## v0.3.5 (2021-02-27)
### Fix
* Correct how named colors are looked up ([`dc14949`](https://github.com/kxgames/glooey/commit/dc149493c36564b8892f09167134fd31c7e155e9))
* Update deprecated code in the themes. ([`9178939`](https://github.com/kxgames/glooey/commit/9178939df55a44dcf0a890aec0aceef2f4989947))
* Correctly initialize the root group ([`825ba6f`](https://github.com/kxgames/glooey/commit/825ba6f0e493965d4d058793076be8be295232e9))
* Prevent root widgets from drawing/undrawing during __init__() ([`5165b50`](https://github.com/kxgames/glooey/commit/5165b5048a5624cb8f6422e5cc2cdfb3af5b7585))

## v0.3.4 (2020-10-05)
### Fix
* Set button foreground widget ([`8cc807f`](https://github.com/kxgames/glooey/commit/8cc807f89f802608470c308963f08dff55e2a90a))

### Documentation
* Describe gotcha with ScrollBox and HBar/VBar ([`c943303`](https://github.com/kxgames/glooey/commit/c943303ead1acee8f58d99c1c0cc916fda196340))
